@@ -491,9 +491,9 @@ class Sale(
 
     @fields.depends('lines', 'currency', methods=['get_tax_amount'])
     def on_change_lines(self):
-        self.untaxed_amount = Decimal('0.0')
-        self.tax_amount = Decimal('0.0')
-        self.total_amount = Decimal('0.0')
+        self.untaxed_amount = Decimal(0)
+        self.tax_amount = Decimal(0)
+        self.total_amount = Decimal(0)
 
         if self.lines:
             for line in self.lines:
@@ -741,6 +741,9 @@ class Sale(
         default.setdefault('sale_date', None)
         default.setdefault('quoted_by')
         default.setdefault('confirmed_by')
+        default.setdefault('untaxed_amount_cache')
+        default.setdefault('tax_amount_cache')
+        default.setdefault('total_amount_cache')
         return super(Sale, cls).copy(sales, default=default)
 
     def check_for_quotation(self):
@@ -947,7 +950,11 @@ class Sale(
     @Workflow.transition('draft')
     @reset_employee('quoted_by', 'confirmed_by')
     def draft(cls, sales):
-        pass
+        cls.write(sales, {
+                'tax_amount_cache': None,
+                'untaxed_amount_cache': None,
+                'total_amount_cache': None,
+                })
 
     @classmethod
     @ModelView.button
@@ -1387,18 +1394,18 @@ class SaleLine(TaxableMixin, sequence_ordered(), ModelSQL, ModelView):
     def on_change_with_amount(self):
         if self.type == 'line':
             currency = self.sale.currency if self.sale else None
-            amount = Decimal(str(self.quantity or '0.0')) * \
-                (self.unit_price or Decimal('0.0'))
+            amount = Decimal(str(self.quantity or 0)) * \
+                (self.unit_price or Decimal(0))
             if currency:
                 return currency.round(amount)
             return amount
-        return Decimal('0.0')
+        return Decimal(0)
 
     def get_amount(self, name):
         if self.type == 'line':
             return self.on_change_with_amount()
         elif self.type == 'subtotal':
-            amount = Decimal('0.0')
+            amount = Decimal(0)
             for line2 in self.sale.lines:
                 if line2.type == 'line':
                     amount += line2.sale.currency.round(
@@ -1406,9 +1413,9 @@ class SaleLine(TaxableMixin, sequence_ordered(), ModelSQL, ModelView):
                 elif line2.type == 'subtotal':
                     if self == line2:
                         break
-                    amount = Decimal('0.0')
+                    amount = Decimal(0)
             return amount
-        return Decimal('0.0')
+        return Decimal(0)
 
     def get_warehouse(self, name):
         return self.sale.warehouse.id if self.sale.warehouse else None
